@@ -1,5 +1,5 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%%% Copyright (c) 2012-2014 Kivra
+%%% Copyright (c) 2012-2015 Kivra
 %%%
 %%% Permission to use, copy, modify, and/or distribute this software for any
 %%% purpose with or without fee is hereby granted, provided that the above
@@ -76,7 +76,7 @@
                     invalid_request | invalid_authorization | invalid_scope |
                     unauthorized_client | unsupported_grant_type |
                     unsupported_response_type | server_error |
-                    temporarily_unavailable.
+                    temporarily_unavailable | atom().
 
 %%%_* Code =============================================================
 %%%_ * API -------------------------------------------------------------
@@ -117,13 +117,17 @@ authorize_password(User, Client, Scope, Ctx0) ->
 -spec authorize_password(user(), client(), rediruri(), scope(), appctx())
                             -> {ok, {appctx(), auth()}} | {error, error()}.
 authorize_password(User, Client, RedirUri, Scope, Ctx0) ->
-    case auth_client(Client, RedirUri, Ctx0) of
-        {error, _}      -> {error, invalid_client};
-        {ok, {Ctx1, C}} ->
-            case auth_user(User, Scope, Ctx1) of
+    case ?BACKEND:get_client_identity(Client,Ctx0) of
+      {error, _}   ->{error, invalid_client};
+      {ok,{Ctx1,C}} ->
+        case ?BACKEND:verify_redirection_uri(C, RedirUri, Ctx1) of
+          {error, _}      -> {error, invalid_client};
+          {ok, Ctx2} ->
+            case auth_user(User, Scope, Ctx2) of
                 {error, _} = E     -> E;
-                {ok, {Ctx2, Auth}} -> {ok, {Ctx2, Auth#a{client=C}}}
+                {ok, {Ctx3, Auth}} -> {ok, {Ctx3, Auth#a{client=C}}}
             end
+        end
     end.
 
 %% @doc Validates a request for an access token from client's credentials.
@@ -242,10 +246,10 @@ issue_token_and_refresh(#a{resowner = undefined}, _Ctx) ->
 issue_token_and_refresh( #a{client=Client, resowner=Owner, scope=Scope, ttl=TTL}
                        , Ctx0 ) ->
     RTTL         = oauth2_config:expiry_time(refresh_token),
-    AccessCtx    = build_context(Client,seconds_since_epoch(TTL),Owner,Scope),
     RefreshCtx   = build_context(Client,seconds_since_epoch(RTTL),Owner,Scope),
-    AccessToken  = ?TOKEN:generate(AccessCtx),
     RefreshToken = ?TOKEN:generate(RefreshCtx),
+    AccessCtx    = build_context(Client,seconds_since_epoch(TTL),Owner,Scope,RefreshToken),
+    AccessToken  = ?TOKEN:generate(AccessCtx),
     {ok, Ctx1}   = ?BACKEND:associate_access_token( AccessToken
                                                   , AccessCtx
                                                   , Ctx0),
@@ -349,7 +353,7 @@ verify_access_token(AccessToken, Ctx0) ->
 %%%_* Private functions ================================================
 auth_user(User, Scope0, Ctx0) ->
     case ?BACKEND:authenticate_user(User, Ctx0) of
-        {error, _}          -> {error, access_denied};
+        {error, _}=E        -> E;
         {ok, {Ctx1, Owner}} ->
             case ?BACKEND:verify_resowner_scope(Owner, Scope0, Ctx1) of
                 {error, _}           -> {error, invalid_scope};
@@ -381,6 +385,9 @@ build_context(Client, ExpiryTime, ResOwner, Scope) ->
     , {<<"expiry_time">>,    ExpiryTime}
     , {<<"scope">>,          Scope} ].
 
+build_context(Client, ExpiryTime, ResOwner, Scope, RefreshToken) ->
+  [{<<"refresh_token">>, RefreshToken} | build_context(Client, ExpiryTime, ResOwner, Scope)].
+
 -spec seconds_since_epoch(integer()) -> non_neg_integer().
 seconds_since_epoch(Diff) ->
     {Mega, Secs, _} = os:timestamp(),
