@@ -1,5 +1,5 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%%% Copyright (c) 2012-2014 Kivra
+%%% Copyright (c) 2012-2015 Kivra
 %%%
 %%% Permission to use, copy, modify, and/or distribute this software for any
 %%% purpose with or without fee is hereby granted, provided that the above
@@ -171,11 +171,11 @@ to_proplist(Response) ->
     response_foldr(Response, fun(Key, Value, Acc) -> [{Key, Value} | Acc] end, []).
 
 -ifndef(pre17).
--ifdef(pre18).
--spec to_map(response()) -> map(binary(), any()).
--else.
--spec to_map(response()) -> #{binary() => any()}.
--endif.
+%-ifdef(pre18).
+%-spec to_map(response()) -> map(binary(), any()).
+%-else.
+%-spec to_map(response()) -> #{binary() => any()}.
+%-endif.
 to_map(Response) ->
     response_foldr(Response, fun(Key, Value, Acc) -> maps:put(Key, Value, Acc) end, maps:new()).
 -endif.
